scriptname AHMSConfigMenu extends SKI_ConfigBase


int function GetVersion()
	return 2
endFunction


Event OnConfigInit()
	Pages = new string[4]
	Pages[0] = "$GeneralSettings"
	Pages[1] = "$CombatSkills"
	Pages[2] = "$MagicSkills"
	Pages[3] = "$StealthSkills"

	AutoLoad()
EndEvent


Event OnConfigClose()
	AHMSScript.CalculatePlayerStats()
EndEvent


;Event OnVersionUpdate(int a_version)
;EndEvent


Event OnPageReset(string page)
	SetCursorFillMode(TOP_TO_BOTTOM)

	if page == "$CombatSkills"
		SetUpCombatPage()
	elseIf page == "$MagicSkills"
		SetUpMagicPage()
	elseIf page == "$StealthSkills"
		SetUpStealthPage()
	else
		AddHeaderOption("$BaseStatus")
		AddSliderOptionST("BASE_HEALTH",  "$BaseHealth",  AHMSBaseHealth.GetValue(),  "{0}")
		AddSliderOptionST("BASE_MAGICKA", "$BaseMagicka", AHMSBaseMagicka.GetValue(), "{0}")
		AddSliderOptionST("BASE_STAMINA", "$BaseStamina", AHMSBaseStamina.GetValue(), "{0}")

		AddHeaderOption("$CarryWeight")
		AddSliderOptionST("BASE_CARRY_WEIGHT", "$BaseCarryWeight", AHMSBaseCarryWeight.GetValue(), "{0}")
		AddSliderOptionST("PER_STAMINA",       "$PerStamina",      AHMSCarryWeightPerStamina.GetValue(), "{2}")

		AddEmptyOption()
		AddTextOptionST("RECALCULATE_STATS", "$RecalculateStats", "")

		AddEmptyOption()

		if PapyrusUtil.GetVersion() > 1
			Int iFlag = OPTION_FLAG_DISABLED

			if JsonUtil.JsonExists(JsonFilename)
				iFlag = OPTION_FLAG_NONE
			endif

			AddToggleOptionST("IS_AUTO_LOAD", "$IsAutoLoad", IsAutoLoad)
			AddToggleOptionST("PROFILE_LOAD", "$ProfileLoad", false, iFlag)
		else
			AddEmptyOption()
			AddTextOption("$PapyrusUtilNotInstalled", "", OPTION_FLAG_DISABLED)
		endif

		SetCursorPosition(1)

		AddEmptyOption()
		AddTextOption("$Health",  Game.GetPlayer().GetActorValue("Health"),  OPTION_FLAG_DISABLED)
		AddTextOption("$Magicka", Game.GetPlayer().GetActorValue("Magicka"), OPTION_FLAG_DISABLED)
		AddTextOption("$Stamina", Game.GetPlayer().GetActorValue("Stamina"), OPTION_FLAG_DISABLED)

		AddEmptyOption()
		AddTextOption("$Current", Game.GetPlayer().GetActorValue("CarryWeight"), OPTION_FLAG_DISABLED)
		AddToggleOptionST("AUTO_BASE_CARRY_WEIGHT", "$AutoBaseCarryWeight", AHMSAutoBaseCarryWeight.GetValueInt() as Bool)

		if PapyrusUtil.GetVersion() > 1
			AddEmptyOption()
			AddEmptyOption()
			AddEmptyOption()
			AddEmptyOption()
			AddToggleOptionST("PROFILE_SAVE", "$ProfileSave", false)
		endif
	endIf	
EndEvent


Function AutoLoad()
	;Debug.Trace("AHMS: MCM AutoLoad")

	if JsonUtil.JsonExists(JsonFilename)
		if JsonUtil.GetIntValue(JsonFilename, "IsAutoLoad")
			LoadProfile()
			AHMSScript.CalculatePlayerStats()
			Debug.Trace("AHMS: AutoLoaded")
		endif
	endif
EndFunction


Function LoadProfile()
	IsAutoLoad = JsonUtil.GetIntValue(JsonFilename, "IsAutoLoad", 1) as Bool

	AHMSBaseHealth.SetValue(JsonUtil.GetFloatValue(JsonFilename, "BaseHealth", 100.0))
	AHMSBaseMagicka.SetValue(JsonUtil.GetFloatValue(JsonFilename, "BaseMagicka", 100.0))
	AHMSBaseStamina.SetValue(JsonUtil.GetFloatValue(JsonFilename, "BaseStamina", 100.0))
	AHMSBaseCarryWeight.SetValue(JsonUtil.GetFloatValue(JsonFilename, "BaseCarryWeight", 300.0))

	AHMSCarryWeightPerStamina.SetValue(JsonUtil.GetFloatValue(JsonFilename, "CarryWeightPerStamina", 1.0))
	AHMSAutoBaseCarryWeight.SetValueInt(JsonUtil.GetIntValue(JsonFilename, "AutoBaseCarryWeight", 1))

	AHMSAlchemyHealth.SetValue(JsonUtil.GetFloatValue(JsonFilename, "AlchemyHealth", 0.5))
	AHMSAlchemyMagicka.SetValue(JsonUtil.GetFloatValue(JsonFilename, "AlchemyMagicka", 0.0))
	AHMSAlchemyStamina.SetValue(JsonUtil.GetFloatValue(JsonFilename, "AlchemyStamina", 0.5))

	AHMSAlterationHealth.SetValue(JsonUtil.GetFloatValue(JsonFilename, "AlterationHealth", 0.0))
	AHMSAlterationMagicka.SetValue(JsonUtil.GetFloatValue(JsonFilename, "AlterationMagicka", 1.0))
	AHMSAlterationStamina.SetValue(JsonUtil.GetFloatValue(JsonFilename, "AlterationStamina", 0.0))

	AHMSBlockHealth.SetValue(JsonUtil.GetFloatValue(JsonFilename, "BlockHealth", 0.5))
	AHMSBlockMagicka.SetValue(JsonUtil.GetFloatValue(JsonFilename, "BlockMagicka", 0.0))
	AHMSBlockStamina.SetValue(JsonUtil.GetFloatValue(JsonFilename, "BlockStamina", 0.5))

	AHMSConjurationHealth.SetValue(JsonUtil.GetFloatValue(JsonFilename, "ConjurationHealth", 0.0))
	AHMSConjurationMagicka.SetValue(JsonUtil.GetFloatValue(JsonFilename, "ConjurationMagicka", 1.0))
	AHMSConjurationStamina.SetValue(JsonUtil.GetFloatValue(JsonFilename, "ConjurationStamina", 0.0))

	AHMSDestructionHealth.SetValue(JsonUtil.GetFloatValue(JsonFilename, "DestructionHealth", 0.0))
	AHMSDestructionMagicka.SetValue(JsonUtil.GetFloatValue(JsonFilename, "DestructionMagicka", 1.0))
	AHMSDestructionStamina.SetValue(JsonUtil.GetFloatValue(JsonFilename, "DestructionStamina", 0.0))

	AHMSEnchantingHealth.SetValue(JsonUtil.GetFloatValue(JsonFilename, "EnchantingHealth", 0.0))
	AHMSEnchantingMagicka.SetValue(JsonUtil.GetFloatValue(JsonFilename, "EnchantingMagicka", 1.0))
	AHMSEnchantingStamina.SetValue(JsonUtil.GetFloatValue(JsonFilename, "EnchantingStamina", 0.0))

	AHMSHeavyArmorHealth.SetValue(JsonUtil.GetFloatValue(JsonFilename, "HeavyArmorHealth", 0.5))
	AHMSHeavyArmorMagicka.SetValue(JsonUtil.GetFloatValue(JsonFilename, "HeavyArmorMagicka", 0.0))
	AHMSHeavyArmorStamina.SetValue(JsonUtil.GetFloatValue(JsonFilename, "HeavyArmorStamina", 0.5))

	AHMSIllusionHealth.SetValue(JsonUtil.GetFloatValue(JsonFilename, "IllusionHealth", 0.0))
	AHMSIllusionMagicka.SetValue(JsonUtil.GetFloatValue(JsonFilename, "IllusionMagicka", 1.0))
	AHMSIllusionStamina.SetValue(JsonUtil.GetFloatValue(JsonFilename, "IllusionStamina", 0.0))

	AHMSLightArmorHealth.SetValue(JsonUtil.GetFloatValue(JsonFilename, "LightArmorHealth", 0.5))
	AHMSLightArmorMagicka.SetValue(JsonUtil.GetFloatValue(JsonFilename, "LightArmorMagicka", 0.0))
	AHMSLightArmorStamina.SetValue(JsonUtil.GetFloatValue(JsonFilename, "LightArmorStamina", 0.5))

	AHMSLockpickingHealth.SetValue(JsonUtil.GetFloatValue(JsonFilename, "LockpickingHealth", 0.5))
	AHMSLockpickingMagicka.SetValue(JsonUtil.GetFloatValue(JsonFilename, "LockpickingMagicka", 0.0))
	AHMSLockpickingStamina.SetValue(JsonUtil.GetFloatValue(JsonFilename, "LockpickingStamina", 0.5))

	AHMSMarksmanHealth.SetValue(JsonUtil.GetFloatValue(JsonFilename, "MarksmanHealth", 0.5))
	AHMSMarksmanMagicka.SetValue(JsonUtil.GetFloatValue(JsonFilename, "MarksmanMagicka", 0.0))
	AHMSMarksmanStamina.SetValue(JsonUtil.GetFloatValue(JsonFilename, "MarksmanStamina", 0.5))

	AHMSOneHandedHealth.SetValue(JsonUtil.GetFloatValue(JsonFilename, "OneHandedHealth", 0.5))
	AHMSOneHandedMagicka.SetValue(JsonUtil.GetFloatValue(JsonFilename, "OneHandedMagicka", 0.0))
	AHMSOneHandedStamina.SetValue(JsonUtil.GetFloatValue(JsonFilename, "OneHandedStamina", 0.5))

	AHMSPickpocketHealth.SetValue(JsonUtil.GetFloatValue(JsonFilename, "PickpocketHealth", 0.5))
	AHMSPickpocketMagicka.SetValue(JsonUtil.GetFloatValue(JsonFilename, "PickpocketMagicka", 0.0))
	AHMSPickpocketStamina.SetValue(JsonUtil.GetFloatValue(JsonFilename, "PickpocketStamina", 0.5))

	AHMSRestorationHealth.SetValue(JsonUtil.GetFloatValue(JsonFilename, "RestorationHealth", 0.0))
	AHMSRestorationMagicka.SetValue(JsonUtil.GetFloatValue(JsonFilename, "RestorationMagicka", 1.0))
	AHMSRestorationStamina.SetValue(JsonUtil.GetFloatValue(JsonFilename, "RestorationStamina", 0.0))

	AHMSSmithingHealth.SetValue(JsonUtil.GetFloatValue(JsonFilename, "SmithingHealth", 0.5))
	AHMSSmithingMagicka.SetValue(JsonUtil.GetFloatValue(JsonFilename, "SmithingMagicka", 0.0))
	AHMSSmithingStamina.SetValue(JsonUtil.GetFloatValue(JsonFilename, "SmithingStamina", 0.5))

	AHMSSneakHealth.SetValue(JsonUtil.GetFloatValue(JsonFilename, "SneakHealth", 0.5))
	AHMSSneakMagicka.SetValue(JsonUtil.GetFloatValue(JsonFilename, "SneakMagicka", 0.0))
	AHMSSneakStamina.SetValue(JsonUtil.GetFloatValue(JsonFilename, "SneakStamina", 0.5))

	AHMSSpeechcraftHealth.SetValue(JsonUtil.GetFloatValue(JsonFilename, "SpeechcraftHealth", 0.5))
	AHMSSpeechcraftMagicka.SetValue(JsonUtil.GetFloatValue(JsonFilename, "SpeechcraftMagicka", 0.0))
	AHMSSpeechcraftStamina.SetValue(JsonUtil.GetFloatValue(JsonFilename, "SpeechcraftStamina", 0.5))

	AHMSTwoHandedHealth.SetValue(JsonUtil.GetFloatValue(JsonFilename, "TwoHandedHealth", 0.5))
	AHMSTwoHandedMagicka.SetValue(JsonUtil.GetFloatValue(JsonFilename, "TwoHandedMagicka", 0.0))
	AHMSTwoHandedStamina.SetValue(JsonUtil.GetFloatValue(JsonFilename, "TwoHandedStamina", 0.5))
EndFunction


Function SaveProfile()
	JsonUtil.SetIntValue(JsonFilename, "IsAutoLoad", IsAutoLoad as Int)

	JsonUtil.SetFloatValue(JsonFilename, "BaseHealth", AHMSBaseHealth.GetValue())
	JsonUtil.SetFloatValue(JsonFilename, "BaseMagicka", AHMSBaseMagicka.GetValue())
	JsonUtil.SetFloatValue(JsonFilename, "BaseStamina", AHMSBaseStamina.GetValue())
	JsonUtil.SetFloatValue(JsonFilename, "BaseCarryWeight", AHMSBaseCarryWeight.GetValue())

	JsonUtil.SetFloatValue(JsonFilename, "CarryWeightPerStamina", AHMSCarryWeightPerStamina.GetValue())
	JsonUtil.SetIntValue(JsonFilename, "AutoBaseCarryWeight", AHMSAutoBaseCarryWeight.GetValueInt())

	JsonUtil.SetFloatValue(JsonFilename, "AlchemyHealth", AHMSAlchemyHealth.GetValue())
	JsonUtil.SetFloatValue(JsonFilename, "AlchemyMagicka", AHMSAlchemyMagicka.GetValue())
	JsonUtil.SetFloatValue(JsonFilename, "AlchemyStamina", AHMSAlchemyStamina.GetValue())

	JsonUtil.SetFloatValue(JsonFilename, "AlterationHealth", AHMSAlterationHealth.GetValue())
	JsonUtil.SetFloatValue(JsonFilename, "AlterationMagicka", AHMSAlterationMagicka.GetValue())
	JsonUtil.SetFloatValue(JsonFilename, "AlterationStamina", AHMSAlterationStamina.GetValue())

	JsonUtil.SetFloatValue(JsonFilename, "BlockHealth", AHMSBlockHealth.GetValue())
	JsonUtil.SetFloatValue(JsonFilename, "BlockMagicka", AHMSBlockMagicka.GetValue())
	JsonUtil.SetFloatValue(JsonFilename, "BlockStamina", AHMSBlockStamina.GetValue())

	JsonUtil.SetFloatValue(JsonFilename, "ConjurationHealth", AHMSConjurationHealth.GetValue())
	JsonUtil.SetFloatValue(JsonFilename, "ConjurationMagicka", AHMSConjurationMagicka.GetValue())
	JsonUtil.SetFloatValue(JsonFilename, "ConjurationStamina", AHMSConjurationStamina.GetValue())

	JsonUtil.SetFloatValue(JsonFilename, "DestructionHealth", AHMSDestructionHealth.GetValue())
	JsonUtil.SetFloatValue(JsonFilename, "DestructionMagicka", AHMSDestructionMagicka.GetValue())
	JsonUtil.SetFloatValue(JsonFilename, "DestructionStamina", AHMSDestructionStamina.GetValue())

	JsonUtil.SetFloatValue(JsonFilename, "EnchantingHealth", AHMSEnchantingHealth.GetValue())
	JsonUtil.SetFloatValue(JsonFilename, "EnchantingMagicka", AHMSEnchantingMagicka.GetValue())
	JsonUtil.SetFloatValue(JsonFilename, "EnchantingStamina", AHMSEnchantingStamina.GetValue())

	JsonUtil.SetFloatValue(JsonFilename, "HeavyArmorHealth", AHMSHeavyArmorHealth.GetValue())
	JsonUtil.SetFloatValue(JsonFilename, "HeavyArmorMagicka", AHMSHeavyArmorMagicka.GetValue())
	JsonUtil.SetFloatValue(JsonFilename, "HeavyArmorStamina", AHMSHeavyArmorStamina.GetValue())

	JsonUtil.SetFloatValue(JsonFilename, "IllusionHealth", AHMSIllusionHealth.GetValue())
	JsonUtil.SetFloatValue(JsonFilename, "IllusionMagicka", AHMSIllusionMagicka.GetValue())
	JsonUtil.SetFloatValue(JsonFilename, "IllusionStamina", AHMSIllusionStamina.GetValue())

	JsonUtil.SetFloatValue(JsonFilename, "LightArmorHealth", AHMSLightArmorHealth.GetValue())
	JsonUtil.SetFloatValue(JsonFilename, "LightArmorMagicka", AHMSLightArmorMagicka.GetValue())
	JsonUtil.SetFloatValue(JsonFilename, "LightArmorStamina", AHMSLightArmorStamina.GetValue())

	JsonUtil.SetFloatValue(JsonFilename, "LockpickingHealth", AHMSLockpickingHealth.GetValue())
	JsonUtil.SetFloatValue(JsonFilename, "LockpickingMagicka", AHMSLockpickingMagicka.GetValue())
	JsonUtil.SetFloatValue(JsonFilename, "LockpickingStamina", AHMSLockpickingStamina.GetValue())

	JsonUtil.SetFloatValue(JsonFilename, "MarksmanHealth", AHMSMarksmanHealth.GetValue())
	JsonUtil.SetFloatValue(JsonFilename, "MarksmanMagicka", AHMSMarksmanMagicka.GetValue())
	JsonUtil.SetFloatValue(JsonFilename, "MarksmanStamina", AHMSMarksmanStamina.GetValue())

	JsonUtil.SetFloatValue(JsonFilename, "OneHandedHealth", AHMSOneHandedHealth.GetValue())
	JsonUtil.SetFloatValue(JsonFilename, "OneHandedMagicka", AHMSOneHandedMagicka.GetValue())
	JsonUtil.SetFloatValue(JsonFilename, "OneHandedStamina", AHMSOneHandedStamina.GetValue())

	JsonUtil.SetFloatValue(JsonFilename, "PickpocketHealth", AHMSPickpocketHealth.GetValue())
	JsonUtil.SetFloatValue(JsonFilename, "PickpocketMagicka", AHMSPickpocketMagicka.GetValue())
	JsonUtil.SetFloatValue(JsonFilename, "PickpocketStamina", AHMSPickpocketStamina.GetValue())

	JsonUtil.SetFloatValue(JsonFilename, "RestorationHealth", AHMSRestorationHealth.GetValue())
	JsonUtil.SetFloatValue(JsonFilename, "RestorationMagicka", AHMSRestorationMagicka.GetValue())
	JsonUtil.SetFloatValue(JsonFilename, "RestorationStamina", AHMSRestorationStamina.GetValue())

	JsonUtil.SetFloatValue(JsonFilename, "SmithingHealth", AHMSSmithingHealth.GetValue())
	JsonUtil.SetFloatValue(JsonFilename, "SmithingMagicka", AHMSSmithingMagicka.GetValue())
	JsonUtil.SetFloatValue(JsonFilename, "SmithingStamina", AHMSSmithingStamina.GetValue())

	JsonUtil.SetFloatValue(JsonFilename, "SneakHealth", AHMSSneakHealth.GetValue())
	JsonUtil.SetFloatValue(JsonFilename, "SneakMagicka", AHMSSneakMagicka.GetValue())
	JsonUtil.SetFloatValue(JsonFilename, "SneakStamina", AHMSSneakStamina.GetValue())

	JsonUtil.SetFloatValue(JsonFilename, "SpeechcraftHealth", AHMSSpeechcraftHealth.GetValue())
	JsonUtil.SetFloatValue(JsonFilename, "SpeechcraftMagicka", AHMSSpeechcraftMagicka.GetValue())
	JsonUtil.SetFloatValue(JsonFilename, "SpeechcraftStamina", AHMSSpeechcraftStamina.GetValue())

	JsonUtil.SetFloatValue(JsonFilename, "TwoHandedHealth", AHMSTwoHandedHealth.GetValue())
	JsonUtil.SetFloatValue(JsonFilename, "TwoHandedMagicka", AHMSTwoHandedMagicka.GetValue())
	JsonUtil.SetFloatValue(JsonFilename, "TwoHandedStamina", AHMSTwoHandedStamina.GetValue())

	JsonUtil.Save(JsonFilename)
EndFunction


Function SetUpCombatPage()
	AddHeaderOption("$Archery")
	AddSliderOptionST("MARKSMAN_HEALTH",  "$Health",  AHMSMarksmanHealth.GetValue(),  "{2}")
	AddSliderOptionST("MARKSMAN_MAGICKA", "$Magicka", AHMSMarksmanMagicka.GetValue(), "{2}")
	AddSliderOptionST("MARKSMAN_STAMINA", "$Stamina", AHMSMarksmanStamina.GetValue(), "{2}")

	AddHeaderOption("$Block")
	AddSliderOptionST("BLOCK_HEALTH",  "$Health",  AHMSBlockHealth.GetValue(),  "{2}")
	AddSliderOptionST("BLOCK_MAGICKA", "$Magicka", AHMSBlockMagicka.GetValue(), "{2}")
	AddSliderOptionST("BLOCK_STAMINA", "$Stamina", AHMSBlockStamina.GetValue(), "{2}")

	AddHeaderOption("$HeavyArmor")
	AddSliderOptionST("HEAVY_ARMOR_HEALTH",  "$Health",  AHMSHeavyArmorHealth.GetValue(),  "{2}")
	AddSliderOptionST("HEAVY_ARMOR_MAGICKA", "$Magicka", AHMSHeavyArmorMagicka.GetValue(), "{2}")
	AddSliderOptionST("HEAVY_ARMOR_STAMINA", "$Stamina", AHMSHeavyArmorStamina.GetValue(), "{2}")

	SetCursorPosition(1)

	AddHeaderOption("$OneHanded")
	AddSliderOptionST("ONE_HANDED_HEALTH",  "$Health",  AHMSOneHandedHealth.GetValue(),  "{2}")
	AddSliderOptionST("ONE_HANDED_MAGICKA", "$Magicka", AHMSOneHandedMagicka.GetValue(), "{2}")
	AddSliderOptionST("ONE_HANDED_STAMINA", "$Stamina", AHMSOneHandedStamina.GetValue(), "{2}")

	AddHeaderOption("$TwoHanded")
	AddSliderOptionST("TWO_HANDED_HEALTH",  "$Health",  AHMSTwoHandedHealth.GetValue(),  "{2}")
	AddSliderOptionST("TWO_HANDED_MAGICKA", "$Magicka", AHMSTwoHandedMagicka.GetValue(), "{2}")
	AddSliderOptionST("TWO_HANDED_STAMINA", "$Stamina", AHMSTwoHandedStamina.GetValue(), "{2}")

	AddHeaderOption("$Smithing")
	AddSliderOptionST("SMITHING_HEALTH",  "$Health",  AHMSSmithingHealth.GetValue(),  "{2}")
	AddSliderOptionST("SMITHING_MAGICKA", "$Magicka", AHMSSmithingMagicka.GetValue(), "{2}")
	AddSliderOptionST("SMITHING_STAMINA", "$Stamina", AHMSSmithingStamina.GetValue(), "{2}")
EndFunction


Function SetUpMagicPage()
	AddHeaderOption("$Alteration")
	AddSliderOptionST("ALTERATION_HEALTH",  "$Health",  AHMSAlterationHealth.GetValue(),  "{2}")
	AddSliderOptionST("ALTERATION_MAGICKA", "$Magicka", AHMSAlterationMagicka.GetValue(), "{2}")
	AddSliderOptionST("ALTERATION_STAMINA", "$Stamina", AHMSAlterationStamina.GetValue(), "{2}")

	AddHeaderOption("$Conjuration")
	AddSliderOptionST("CONJURATION_HEALTH",  "$Health",  AHMSConjurationHealth.GetValue(),  "{2}")
	AddSliderOptionST("CONJURATION_MAGICKA", "$Magicka", AHMSConjurationMagicka.GetValue(), "{2}")
	AddSliderOptionST("CONJURATION_STAMINA", "$Stamina", AHMSConjurationStamina.GetValue(), "{2}")

	AddHeaderOption("$Destruction")
	AddSliderOptionST("DESTRUCTION_HEALTH",  "$Health",  AHMSDestructionHealth.GetValue(),  "{2}")
	AddSliderOptionST("DESTRUCTION_MAGICKA", "$Magicka", AHMSDestructionMagicka.GetValue(), "{2}")
	AddSliderOptionST("DESTRUCTION_STAMINA", "$Stamina", AHMSDestructionStamina.GetValue(), "{2}")

	SetCursorPosition(1)

	AddHeaderOption("$Enchanting")
	AddSliderOptionST("ENCHANTING_HEALTH",  "$Health",  AHMSEnchantingHealth.GetValue(),  "{2}")
	AddSliderOptionST("ENCHANTING_MAGICKA", "$Magicka", AHMSEnchantingMagicka.GetValue(), "{2}")
	AddSliderOptionST("ENCHANTING_STAMINA", "$Stamina", AHMSEnchantingStamina.GetValue(), "{2}")

	AddHeaderOption("$Illusion")
	AddSliderOptionST("ILLUSION_HEALTH",  "$Health",  AHMSIllusionHealth.GetValue(),  "{2}")
	AddSliderOptionST("ILLUSION_MAGICKA", "$Magicka", AHMSIllusionMagicka.GetValue(), "{2}")
	AddSliderOptionST("ILLUSION_STAMINA", "$Stamina", AHMSIllusionStamina.GetValue(), "{2}")

	AddHeaderOption("$Restoration")
	AddSliderOptionST("RESTORATION_HEALTH",  "$Health",  AHMSRestorationHealth.GetValue(),  "{2}")
	AddSliderOptionST("RESTORATION_MAGICKA", "$Magicka", AHMSRestorationMagicka.GetValue(), "{2}")
	AddSliderOptionST("RESTORATION_STAMINA", "$Stamina", AHMSRestorationStamina.GetValue(), "{2}")
EndFunction


Function SetUpStealthPage()
	AddHeaderOption("$Alchemy")
	AddSliderOptionST("ALCHEMY_HEALTH",  "$Health",  AHMSAlchemyHealth.GetValue(),  "{2}")
	AddSliderOptionST("ALCHEMY_MAGICKA", "$Magicka", AHMSAlchemyMagicka.GetValue(), "{2}")
	AddSliderOptionST("ALCHEMY_STAMINA", "$Stamina", AHMSAlchemyStamina.GetValue(), "{2}")

	AddHeaderOption("$LightArmor")
	AddSliderOptionST("LIGHT_ARMOR_HEALTH",  "$Health",  AHMSLightArmorHealth.GetValue(),  "{2}")
	AddSliderOptionST("LIGHT_ARMOR_MAGICKA", "$Magicka", AHMSLightArmorMagicka.GetValue(), "{2}")
	AddSliderOptionST("LIGHT_ARMOR_STAMINA", "$Stamina", AHMSLightArmorStamina.GetValue(), "{2}")

	AddHeaderOption("$Lockpicking")
	AddSliderOptionST("LOCKPICKING_HEALTH",  "$Health",  AHMSLockpickingHealth.GetValue(),  "{2}")
	AddSliderOptionST("LOCKPICKING_MAGICKA", "$Magicka", AHMSLockpickingMagicka.GetValue(), "{2}")
	AddSliderOptionST("LOCKPICKING_STAMINA", "$Stamina", AHMSLockpickingStamina.GetValue(), "{2}")

	SetCursorPosition(1)

	AddHeaderOption("$Pickpocket")
	AddSliderOptionST("PICKPOCKET_HEALTH",  "$Health",  AHMSPickpocketHealth.GetValue(),  "{2}")
	AddSliderOptionST("PICKPOCKET_MAGICKA", "$Magicka", AHMSPickpocketMagicka.GetValue(), "{2}")
	AddSliderOptionST("PICKPOCKET_STAMINA", "$Stamina", AHMSPickpocketStamina.GetValue(), "{2}")

	AddHeaderOption("$Sneak")
	AddSliderOptionST("SNEAK_HEALTH",  "$Health",  AHMSSneakHealth.GetValue(),  "{2}")
	AddSliderOptionST("SNEAK_MAGICKA", "$Magicka", AHMSSneakMagicka.GetValue(), "{2}")
	AddSliderOptionST("SNEAK_STAMINA", "$Stamina", AHMSSneakStamina.GetValue(), "{2}")

	AddHeaderOption("$Speechcraft")
	AddSliderOptionST("SPEECH_HEALTH",  "$Health",  AHMSSpeechcraftHealth.GetValue(),  "{2}")
	AddSliderOptionST("SPEECH_MAGICKA", "$Magicka", AHMSSpeechcraftMagicka.GetValue(), "{2}")
	AddSliderOptionST("SPEECH_STAMINA", "$Stamina", AHMSSpeechcraftStamina.GetValue(), "{2}")
EndFunction


State BASE_HEALTH
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSBaseHealth.GetValue())
		SetSliderDialogDefaultValue(0.0)
		SetSliderDialogRange(0.0, 1000.0)
		SetSliderDialogInterval(1)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSBaseHealth.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSBaseHealth.SetValue(0.0)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent

	Event OnHighlightST()
		SetInfoText("$BaseHealthHint")
	EndEvent
EndState


State BASE_MAGICKA
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSBaseMagicka.GetValue())
		SetSliderDialogDefaultValue(0.0)
		SetSliderDialogRange(0.0, 1000.0)
		SetSliderDialogInterval(1)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSBaseMagicka.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSBaseMagicka.SetValue(0.0)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent

	Event OnHighlightST()
		SetInfoText("$BaseMagickaHint")
	EndEvent
EndState


State BASE_STAMINA
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSBaseStamina.GetValue())
		SetSliderDialogDefaultValue(0.0)
		SetSliderDialogRange(0.0, 1000.0)
		SetSliderDialogInterval(1)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSBaseStamina.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSBaseStamina.SetValue(0.0)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent

	Event OnHighlightST()
		SetInfoText("$BaseStaminaHint")
	EndEvent
EndState


State BASE_CARRY_WEIGHT
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSBaseCarryWeight.GetValue())
		SetSliderDialogDefaultValue(300.0)
		SetSliderDialogRange(0.0, 1000.0)
		SetSliderDialogInterval(1)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSBaseCarryWeight.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSBaseCarryWeight.SetValue(300.0)
		SetSliderOptionValueST(300.0, "{0}")
	EndEvent

	Event OnHighlightST()
		SetInfoText("$BaseCarryWeightHint")
	EndEvent
EndState


State PER_STAMINA
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSCarryWeightPerStamina.GetValue())
		SetSliderDialogDefaultValue(1.0)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSCarryWeightPerStamina.SetValue(value)
		SetSliderOptionValueST(value, "{2}")
	EndEvent

	Event OnDefaultST()
		AHMSCarryWeightPerStamina.SetValue(1.0)
		SetSliderOptionValueST(1.0, "{2}")
	EndEvent

	Event OnHighlightST()
		SetInfoText("$PerStaminaHint")
	EndEvent
EndState


State AUTO_BASE_CARRY_WEIGHT
	Event OnSelectST()
		Bool value = AHMSAutoBaseCarryWeight.GetValueInt() as Bool
		value = !value
		SetToggleOptionValueST(value)
		AHMSAutoBaseCarryWeight.SetValueInt(value as int)
	EndEvent

	Event OnHighlightST()
		SetInfoText("$AutoBaseCarryWeightHint")
	EndEvent
EndState


State RECALCULATE_STATS
	Event OnSelectST()
		SetTextOptionValueST("$Recalculating")
		AHMSScript.CalculatePlayerStats()
		ForcePageReset()
	EndEvent

	Event OnHighlightST()
		SetInfoText("$RecalculateStatsHint")
	EndEvent
EndState


State IS_AUTO_LOAD
	Event OnSelectST()
		IsAutoLoad = !IsAutoLoad
		SetToggleOptionValueST(IsAutoLoad)
	EndEvent
	
	Event OnDefaultST()
		IsAutoLoad = true
		SetToggleOptionValueST(IsAutoLoad)
	EndEvent

	Event OnHighlightST()
		SetInfoText("$IsAutoLoadHint")
	EndEvent
EndState


State PROFILE_SAVE
	Event OnSelectST()
		SetToggleOptionValueST(true)

		if !ShowMessage("$AskProfileSave")
			SetToggleOptionValueST(false)
			return
		endif

		SaveProfile()
		ShowMessage("$ProfileSaved", false)
		SetToggleOptionValueST(false)
	EndEvent

	Event OnHighlightST()
		SetInfoText("$ProfileSaveHint")
	EndEvent
EndState


State PROFILE_LOAD
	Event OnSelectST()
		SetToggleOptionValueST(true)

		if !ShowMessage("$AskProfileLoad")
			SetToggleOptionValueST(false)
			return
		endif

		if JsonUtil.JsonExists(JsonFilename)
			LoadProfile()
			AHMSScript.CalculatePlayerStats()
			ForcePageReset()
			ShowMessage("$ProfileLoaded", false)
		else
			ShowMessage("$ProfileNotFound", false)
		endif

		SetToggleOptionValueST(false)
	EndEvent

	Event OnHighlightST()
		SetInfoText("$ProfileLoadHint")
	EndEvent
EndState


State ALCHEMY_HEALTH
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSAlchemyHealth.GetValue())
		SetSliderDialogDefaultValue(0.5)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSAlchemyHealth.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSAlchemyHealth.SetValue(0.5)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State ALCHEMY_MAGICKA
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSAlchemyMagicka.GetValue())
		SetSliderDialogDefaultValue(0.0)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSAlchemyMagicka.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSAlchemyMagicka.SetValue(0.0)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State ALCHEMY_STAMINA
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSAlchemyStamina.GetValue())
		SetSliderDialogDefaultValue(0.5)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSAlchemyStamina.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSAlchemyStamina.SetValue(0.5)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State ALTERATION_HEALTH
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSAlterationHealth.GetValue())
		SetSliderDialogDefaultValue(0.0)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSAlterationHealth.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSAlterationHealth.SetValue(0.0)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State ALTERATION_MAGICKA
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSAlterationMagicka.GetValue())
		SetSliderDialogDefaultValue(1.0)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSAlterationMagicka.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSAlterationMagicka.SetValue(1.0)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State ALTERATION_STAMINA
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSAlterationStamina.GetValue())
		SetSliderDialogDefaultValue(0.0)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSAlterationStamina.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSAlterationStamina.SetValue(0.0)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State BLOCK_HEALTH
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSBlockHealth.GetValue())
		SetSliderDialogDefaultValue(0.5)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSBlockHealth.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSBlockHealth.SetValue(0.5)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State BLOCK_MAGICKA
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSBlockMagicka.GetValue())
		SetSliderDialogDefaultValue(0.0)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSBlockMagicka.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSBlockMagicka.SetValue(0.0)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State BLOCK_STAMINA
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSBlockStamina.GetValue())
		SetSliderDialogDefaultValue(0.5)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSBlockStamina.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSBlockStamina.SetValue(0.5)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State CONJURATION_HEALTH
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSConjurationHealth.GetValue())
		SetSliderDialogDefaultValue(0.0)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSConjurationHealth.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSConjurationHealth.SetValue(0.0)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State CONJURATION_MAGICKA
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSConjurationMagicka.GetValue())
		SetSliderDialogDefaultValue(1.0)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSConjurationMagicka.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSConjurationMagicka.SetValue(1.0)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State CONJURATION_STAMINA
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSConjurationStamina.GetValue())
		SetSliderDialogDefaultValue(0.0)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSConjurationStamina.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSConjurationStamina.SetValue(0.0)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State DESTRUCTION_HEALTH
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSDestructionHealth.GetValue())
		SetSliderDialogDefaultValue(0.0)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSDestructionHealth.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSDestructionHealth.SetValue(0.0)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State DESTRUCTION_MAGICKA
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSDestructionMagicka.GetValue())
		SetSliderDialogDefaultValue(1.0)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSDestructionMagicka.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSDestructionMagicka.SetValue(1.0)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State DESTRUCTION_STAMINA
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSDestructionStamina.GetValue())
		SetSliderDialogDefaultValue(0.0)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSDestructionStamina.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSDestructionStamina.SetValue(0.0)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State ENCHANTING_HEALTH
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSEnchantingHealth.GetValue())
		SetSliderDialogDefaultValue(0.0)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSEnchantingHealth.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSEnchantingHealth.SetValue(0.0)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State ENCHANTING_MAGICKA
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSEnchantingMagicka.GetValue())
		SetSliderDialogDefaultValue(1.0)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSEnchantingMagicka.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSEnchantingMagicka.SetValue(1.0)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State ENCHANTING_STAMINA
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSEnchantingStamina.GetValue())
		SetSliderDialogDefaultValue(0.0)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSEnchantingStamina.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSEnchantingStamina.SetValue(0.0)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State ILLUSION_HEALTH
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSIllusionHealth.GetValue())
		SetSliderDialogDefaultValue(0.0)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSIllusionHealth.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSIllusionHealth.SetValue(0.0)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State ILLUSION_MAGICKA
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSIllusionMagicka.GetValue())
		SetSliderDialogDefaultValue(1.0)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSIllusionMagicka.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSIllusionMagicka.SetValue(1.0)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State ILLUSION_STAMINA
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSIllusionStamina.GetValue())
		SetSliderDialogDefaultValue(0.0)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSIllusionStamina.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSIllusionStamina.SetValue(0.0)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State LIGHT_ARMOR_HEALTH
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSLightArmorHealth.GetValue())
		SetSliderDialogDefaultValue(0.5)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSLightArmorHealth.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSLightArmorHealth.SetValue(0.5)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State LIGHT_ARMOR_MAGICKA
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSLightArmorMagicka.GetValue())
		SetSliderDialogDefaultValue(0.0)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSLightArmorMagicka.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSLightArmorMagicka.SetValue(0.0)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State LIGHT_ARMOR_STAMINA
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSLightArmorStamina.GetValue())
		SetSliderDialogDefaultValue(0.5)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSLightArmorStamina.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSLightArmorStamina.SetValue(0.5)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State LOCKPICKING_HEALTH
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSLockpickingHealth.GetValue())
		SetSliderDialogDefaultValue(0.5)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSLockpickingHealth.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSLockpickingHealth.SetValue(0.5)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State LOCKPICKING_MAGICKA
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSLockpickingMagicka.GetValue())
		SetSliderDialogDefaultValue(0.0)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSLockpickingMagicka.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSLockpickingMagicka.SetValue(0.0)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State LOCKPICKING_STAMINA
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSLockpickingStamina.GetValue())
		SetSliderDialogDefaultValue(0.5)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSLockpickingStamina.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSLockpickingStamina.SetValue(0.5)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State MARKSMAN_HEALTH
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSMarksmanHealth.GetValue())
		SetSliderDialogDefaultValue(0.5)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSMarksmanHealth.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSMarksmanHealth.SetValue(0.5)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State MARKSMAN_MAGICKA
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSMarksmanMagicka.GetValue())
		SetSliderDialogDefaultValue(0.0)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSMarksmanMagicka.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSMarksmanMagicka.SetValue(0.0)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State MARKSMAN_STAMINA
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSMarksmanStamina.GetValue())
		SetSliderDialogDefaultValue(0.5)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSMarksmanStamina.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSMarksmanStamina.SetValue(0.5)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State ONE_HANDED_HEALTH
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSOneHandedHealth.GetValue())
		SetSliderDialogDefaultValue(0.5)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSOneHandedHealth.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSOneHandedHealth.SetValue(0.5)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State ONE_HANDED_MAGICKA
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSOneHandedMagicka.GetValue())
		SetSliderDialogDefaultValue(0.0)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSOneHandedMagicka.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSOneHandedMagicka.SetValue(0.0)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State ONE_HANDED_STAMINA
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSOneHandedStamina.GetValue())
		SetSliderDialogDefaultValue(0.5)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSOneHandedStamina.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSOneHandedStamina.SetValue(0.5)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State PICKPOCKET_HEALTH
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSPickpocketHealth.GetValue())
		SetSliderDialogDefaultValue(0.5)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSPickpocketHealth.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSPickpocketHealth.SetValue(0.5)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State PICKPOCKET_MAGICKA
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSPickpocketMagicka.GetValue())
		SetSliderDialogDefaultValue(0.0)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSPickpocketMagicka.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSPickpocketMagicka.SetValue(0.0)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State PICKPOCKET_STAMINA
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSPickpocketStamina.GetValue())
		SetSliderDialogDefaultValue(0.5)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSPickpocketStamina.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSPickpocketStamina.SetValue(0.5)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State RESTORATION_HEALTH
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSRestorationHealth.GetValue())
		SetSliderDialogDefaultValue(0.0)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSRestorationHealth.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSRestorationHealth.SetValue(0.0)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State RESTORATION_MAGICKA
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSRestorationMagicka.GetValue())
		SetSliderDialogDefaultValue(1.0)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSRestorationMagicka.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSRestorationMagicka.SetValue(1.0)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State RESTORATION_STAMINA
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSRestorationStamina.GetValue())
		SetSliderDialogDefaultValue(0.0)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSRestorationStamina.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSRestorationStamina.SetValue(0.0)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State SMITHING_HEALTH
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSSmithingHealth.GetValue())
		SetSliderDialogDefaultValue(0.5)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSSmithingHealth.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSSmithingHealth.SetValue(0.5)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State SMITHING_MAGICKA
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSSmithingMagicka.GetValue())
		SetSliderDialogDefaultValue(0.0)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSSmithingMagicka.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSSmithingMagicka.SetValue(0.0)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State SMITHING_STAMINA
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSSmithingStamina.GetValue())
		SetSliderDialogDefaultValue(0.5)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSSmithingStamina.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSSmithingStamina.SetValue(0.5)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State SNEAK_HEALTH
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSSneakHealth.GetValue())
		SetSliderDialogDefaultValue(0.5)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSSneakHealth.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSSneakHealth.SetValue(0.5)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State SNEAK_MAGICKA
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSSneakMagicka.GetValue())
		SetSliderDialogDefaultValue(0.0)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSSneakMagicka.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSSneakMagicka.SetValue(0.0)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State SNEAK_STAMINA
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSSneakStamina.GetValue())
		SetSliderDialogDefaultValue(0.5)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSSneakStamina.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSSneakStamina.SetValue(0.5)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State SPEECHCRAFT_HEALTH
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSSpeechcraftHealth.GetValue())
		SetSliderDialogDefaultValue(0.5)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSSpeechcraftHealth.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSSpeechcraftHealth.SetValue(0.5)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State SPEECHCRAFT_MAGICKA
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSSpeechcraftMagicka.GetValue())
		SetSliderDialogDefaultValue(0.0)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSSpeechcraftMagicka.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSSpeechcraftMagicka.SetValue(0.0)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State SPEECHCRAFT_STAMINA
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSSpeechcraftStamina.GetValue())
		SetSliderDialogDefaultValue(0.5)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSSpeechcraftStamina.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSSpeechcraftStamina.SetValue(0.5)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State TWO_HANDED_HEALTH
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSTwoHandedHealth.GetValue())
		SetSliderDialogDefaultValue(0.5)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSTwoHandedHealth.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSTwoHandedHealth.SetValue(0.5)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State TWO_HANDED_MAGICKA
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSTwoHandedMagicka.GetValue())
		SetSliderDialogDefaultValue(0.0)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSTwoHandedMagicka.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSTwoHandedMagicka.SetValue(0.0)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


State TWO_HANDED_STAMINA
	Event OnSliderOpenST()
		SetSliderDialogStartValue(AHMSTwoHandedStamina.GetValue())
		SetSliderDialogDefaultValue(0.5)
		SetSliderDialogRange(0.0, 10.0)
		SetSliderDialogInterval(0.01)
	EndEvent

	Event OnSliderAcceptST(float value)
		AHMSTwoHandedStamina.SetValue(value)
		SetSliderOptionValueST(value, "{0}")
	EndEvent

	Event OnDefaultST()
		AHMSTwoHandedStamina.SetValue(0.5)
		SetSliderOptionValueST(0.0, "{0}")
	EndEvent
EndState


Bool IsAutoLoad = true
String JsonFilename = "AHMS.json"

AutoHealthMagickaStamina Property AHMSScript  auto

GlobalVariable Property AHMSBaseHealth auto
GlobalVariable Property AHMSBaseMagicka auto
GlobalVariable Property AHMSBaseStamina auto
GlobalVariable Property AHMSBaseCarryWeight Auto

GlobalVariable Property AHMSAutoBaseCarryWeight Auto
GlobalVariable Property AHMSCarryWeightPerStamina auto

GlobalVariable property AHMSOneHandedHealth auto
GlobalVariable property AHMSOneHandedMagicka auto
GlobalVariable property AHMSOneHandedStamina auto

GlobalVariable property AHMSTwoHandedHealth auto
GlobalVariable property AHMSTwoHandedMagicka auto
GlobalVariable property AHMSTwoHandedStamina auto

GlobalVariable property AHMSMarksmanHealth auto
GlobalVariable property AHMSMarksmanMagicka auto
GlobalVariable property AHMSMarksmanStamina auto

GlobalVariable property AHMSBlockHealth auto
GlobalVariable property AHMSBlockMagicka auto
GlobalVariable property AHMSBlockStamina auto

GlobalVariable property AHMSSmithingHealth auto
GlobalVariable property AHMSSmithingMagicka auto
GlobalVariable property AHMSSmithingStamina auto

GlobalVariable property AHMSHeavyArmorHealth auto
GlobalVariable property AHMSHeavyArmorMagicka auto
GlobalVariable property AHMSHeavyArmorStamina auto

GlobalVariable property AHMSLightArmorHealth auto
GlobalVariable property AHMSLightArmorMagicka auto
GlobalVariable property AHMSLightArmorStamina auto

GlobalVariable property AHMSPickpocketHealth auto
GlobalVariable property AHMSPickpocketMagicka auto
GlobalVariable property AHMSPickpocketStamina auto

GlobalVariable property AHMSLockpickingHealth auto
GlobalVariable property AHMSLockpickingMagicka auto
GlobalVariable property AHMSLockpickingStamina auto

GlobalVariable property AHMSSneakHealth auto
GlobalVariable property AHMSSneakMagicka auto
GlobalVariable property AHMSSneakStamina auto

GlobalVariable property AHMSAlchemyHealth auto
GlobalVariable property AHMSAlchemyMagicka auto
GlobalVariable property AHMSAlchemyStamina auto

GlobalVariable property AHMSSpeechcraftHealth auto
GlobalVariable property AHMSSpeechcraftMagicka auto
GlobalVariable property AHMSSpeechcraftStamina auto

GlobalVariable property AHMSAlterationHealth auto
GlobalVariable property AHMSAlterationMagicka auto
GlobalVariable property AHMSAlterationStamina auto

GlobalVariable property AHMSConjurationHealth auto
GlobalVariable property AHMSConjurationMagicka auto
GlobalVariable property AHMSConjurationStamina auto

GlobalVariable property AHMSDestructionHealth auto
GlobalVariable property AHMSDestructionMagicka auto
GlobalVariable property AHMSDestructionStamina auto

GlobalVariable property AHMSIllusionHealth auto
GlobalVariable property AHMSIllusionMagicka auto
GlobalVariable property AHMSIllusionStamina auto

GlobalVariable property AHMSRestorationHealth auto
GlobalVariable property AHMSRestorationMagicka auto
GlobalVariable property AHMSRestorationStamina auto

GlobalVariable property AHMSEnchantingHealth auto
GlobalVariable property AHMSEnchantingMagicka auto
GlobalVariable property AHMSEnchantingStamina auto